pub async fn confirm_customization_details(
configuration: &Configuration,
amazon_order_id: &str,
marketplace_ids: Vec<String>,
body: CreateConfirmCustomizationDetailsRequest
) -> Result<CreateConfirmCustomizationDetailsResponse, Error>Expand description
Sends a message asking a buyer to provide or verify customization details such as name spelling, images, initials, etc. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 5 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.