pub async fn create_amazon_motors(
    configuration: &Configuration,
    amazon_order_id: &str,
    marketplace_ids: Vec<String>,
    body: CreateAmazonMotorsRequest
) -> Result<CreateAmazonMotorsResponse, Error>
Sends a message to a buyer to provide details about an Amazon Motors order. This message can only be sent by Amazon Motors sellers. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 5 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.