pub async fn create_confirm_delivery_details(
    configuration: &Configuration,
    amazon_order_id: &str,
    marketplace_ids: Vec<String>,
    body: CreateConfirmDeliveryDetailsRequest
) -> Result<CreateConfirmDeliveryDetailsResponse, Error>
Sends a message to a buyer to arrange a delivery or to confirm contact information for making a delivery. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 5 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.