pub async fn create_confirm_service_details(
    configuration: &Configuration,
    amazon_order_id: &str,
    marketplace_ids: Vec<String>,
    body: CreateConfirmServiceDetailsRequest
) -> Result<CreateConfirmServiceDetailsResponse, Error>
Sends a message to contact a Home Service customer to arrange a service call or to gather information prior to a service call. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 5 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.