pub async fn create_digital_access_key(
    configuration: &Configuration,
    amazon_order_id: &str,
    marketplace_ids: Vec<String>,
    body: CreateDigitalAccessKeyRequest
) -> Result<CreateDigitalAccessKeyResponse, Error>
Sends a message to a buyer to share a digital access key needed to utilize digital content in their order. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 5 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.