pub async fn get_messaging_actions_for_order(
    configuration: &Configuration,
    amazon_order_id: &str,
    marketplace_ids: Vec<String>
) -> Result<GetMessagingActionsForOrderResponse, Error>
Returns a list of message types that are available for an order that you specify. A message type is represented by an actions object, which contains a path and query parameter(s). You can use the path and parameter(s) to call an operation that sends a message. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 5 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.