Function amazon_sp_messaging::apis::messaging_api::create_amazon_motors
source · [−]pub async fn create_amazon_motors(
configuration: &Configuration,
amazon_order_id: &str,
marketplace_ids: Vec<String>,
body: CreateAmazonMotorsRequest
) -> Result<CreateAmazonMotorsResponse, Error>Expand description
Sends a message to a buyer to provide details about an Amazon Motors order. This message can only be sent by Amazon Motors sellers. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 5 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.