Function amazon_sp_messaging::apis::messaging_api::create_legal_disclosure
source · [−]pub async fn create_legal_disclosure(
configuration: &Configuration,
amazon_order_id: &str,
marketplace_ids: Vec<String>,
body: CreateLegalDisclosureRequest
) -> Result<CreateLegalDisclosureResponse, Error>Expand description
Sends a critical message that contains documents that a seller is legally obligated to provide to the buyer. This message should only be used to deliver documents that are required by law. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 5 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.