pub async fn create_negative_feedback_removal(
configuration: &Configuration,
amazon_order_id: &str,
marketplace_ids: Vec<String>
) -> Result<CreateNegativeFeedbackRemovalResponse, Error>Expand description
Sends a non-critical message that asks a buyer to remove their negative feedback. This message should only be sent after the seller has resolved the buyer’s problem. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 5 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.