Function amazon_sp_messaging::apis::messaging_api::create_unexpected_problem
source · [−]pub async fn create_unexpected_problem(
configuration: &Configuration,
amazon_order_id: &str,
marketplace_ids: Vec<String>,
body: CreateUnexpectedProblemRequest
) -> Result<CreateUnexpectedProblemResponse, Error>Expand description
Sends a critical message to a buyer that an unexpected problem was encountered affecting the completion of the order. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 5 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.