Function amazon_sp_messaging::apis::messaging_api::create_warranty
source · [−]pub async fn create_warranty(
configuration: &Configuration,
amazon_order_id: &str,
marketplace_ids: Vec<String>,
body: CreateWarrantyRequest
) -> Result<CreateWarrantyResponse, Error>Expand description
Sends a message to a buyer to provide details about warranty information on a purchase in their order. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 1 | 5 | For more information, see "Usage Plans and Rate Limits" in the Selling Partner API documentation.